@@ -8,4 +8,9 @@ from .result import Result, Ok, Err
 from .future import Future
 from .reader import Reader
 
-version = "v0.4.3"
+try:
+    from .fastapi import MonadicResponseMiddleware
+except ImportError:
+    pass
+
+version = "v0.4.4"
